@@ -277,10 +277,10 @@ void trainThread::run()
 		for(i=0;i<130;i++)
 		{
 		mkmove++;
-if(!pFig->speed)usleep(500000);
+		if(!pFig->speed)usleep(500000);
 		if(pFig->nugame){i=0;pFig->nugame=0;}
 		pFig->pieces.PlayAmen=!pFig->pieces.PlayAmen;
-if(pFig->pieces.PlayAmen)
+		if(pFig->pieces.PlayAmen)
 {mike->emg=pFig->pieces.enemymen;mike->ekg=pFig->pieces.enemykings;mike->cmg=pFig->pieces.compmen;mike->ckg=pFig->pieces.compkings;}
 else	{mike->cmg=pFig->pieces.enemymen;mike->ckg=pFig->pieces.enemykings;mike->emg=pFig->pieces.compmen;mike->ekg=pFig->pieces.compkings;}
 
@@ -293,7 +293,8 @@ else	{mike->cmg=pFig->pieces.enemymen;mike->ckg=pFig->pieces.enemykings;mike->em
 	if(pFig->killer)break;
 	}
 	playing.unlock();mkmove--;
-	pFig->nugame=0;pFig->pieces.cpturn=0;pFig->Ato=0;
+	pFig->nugame=0;pFig->Ato=0;
+	if(!pFig->pieces.PlayAmen)pFig->pieces.cpturn=0;
 	return;			 					// thread completed successfully
 }						 
 
